@@ -1,6 +1,6 @@
 // This module implements the portability layer for the Qt port of Scintilla.
 //
-// Copyright (c) 2003
+// Copyright (c) 2004
 // 	Riverbank Computing Limited <info@riverbankcomputing.co.uk>
 // 
 // This file is part of QScintilla.
@@ -110,7 +110,7 @@ Font::~Font()
 {
 }
 
-void Font::Create(const char *faceName,int,int size,bool bold,bool italic)
+void Font::Create(const char *faceName,int,int size,bool bold,bool italic,bool)
 {
 	Release();
 
@@ -330,29 +330,28 @@ void SurfaceImpl::Ellipse(PRectangle rc,ColourAllocated fore,
 void SurfaceImpl::Copy(PRectangle rc,Point from,Surface &surfaceSource)
 {
 	SurfaceImpl &si = static_cast<SurfaceImpl &>(surfaceSource);
-	QPixmap *pm = static_cast<QPixmap *>(si.painter -> device());
+	QPaintDevice *spd = si.painter -> device();
+	QPaintDevice *dpd = painter -> device();
 
-	if (pm)
-		painter -> drawPixmap(rc.left,rc.top,*pm,from.x,from.y,
-				      rc.right - rc.left,rc.bottom - rc.top);
+	if (spd && dpd)
+	{
+		si.painter -> end();
+		painter -> end();
+
+		bitBlt(dpd,rc.left,rc.top,spd,from.x,from.y,
+		       rc.right - rc.left,rc.bottom - rc.top);
+
+		si.painter -> begin(spd);
+		painter -> begin(dpd);
+	}
 }
 
 void SurfaceImpl::DrawTextNoClip(PRectangle rc,Font &font_,int ybase,
 				 const char *s,int len,ColourAllocated fore,
 				 ColourAllocated back)
 {
-	QString qs = convertText(s,len);
-
-	// rc contains the area we want to fill completely, but it includes a
-	// gap above and below the text.  This means we can't leave it to
-	// QPainter::drawText() to get the background colour right - we have to
-	// explicitly handle it and use QPainter::drawText() to just handle the
-	// text.
 	FillRectangle(rc,back);
-	setFont(font_);
-	painter -> setBackgroundMode(Qt::TransparentMode);
-	painter -> setPen(convertColour(fore));
-	painter -> drawText(rc.left,ybase,qs);
+	DrawTextTransparent(rc,font_,ybase,s,len,fore);
 }
 
 void SurfaceImpl::DrawTextClipped(PRectangle rc,Font &font_,int ybase,
@@ -371,7 +370,6 @@ void SurfaceImpl::DrawTextTransparent(PRectangle rc,Font &font_,int ybase,
 	QString qs = convertText(s,len);
 
 	setFont(font_);
-	painter -> setBackgroundMode(Qt::TransparentMode);
 	painter -> setPen(convertColour(fore));
 	painter -> drawText(rc.left,ybase,qs);
 }
@@ -771,7 +769,11 @@ unsigned int Platform::DoubleClickTime()
 
 bool Platform::MouseButtonBounce()
 {
+#if defined(Q_OS_WIN)
+	return false;
+#else
 	return true;
+#endif
 }
 
 void Platform::DebugDisplay(const char *s)
