@@ -2,7 +2,7 @@
 // Scintilla.  It is modelled on QTextEdit - a method of the same name should
 // behave in the same way.
 //
-// Copyright (c) 2003
+// Copyright (c) 2004
 // 	Riverbank Computing Limited <info@riverbankcomputing.co.uk>
 // 
 // This file is part of QScintilla.
@@ -38,7 +38,10 @@
 
 
 // The default fold margin width.
-const int defaultFoldMarginWidth = 14;
+static const int defaultFoldMarginWidth = 14;
+
+// The default set of characters that make up a word.
+static const char *defaultWordChars = "_abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ";
 
 
 // The ctor.
@@ -50,15 +53,6 @@ QextScintilla::QextScintilla(QWidget *parent,const char *name,WFlags f) :
 				acSource(AcsDocument), acThresh(-1), acAPIs(0),
 				ctAPIs(0), maxCallTips(-1), showSingle(FALSE)
 {
-	// Scintilla doesn't provide a mechanism to read the characters it
-	// considers to make up words.
-	wordChars = "_abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ";
-
-	// Only signal if the text (rather than style) has changed.
-	SendScintilla(SCI_SETMODEVENTMASK,SC_MOD_INSERTTEXT|SC_MOD_DELETETEXT);
-	connect(this,SIGNAL(SCEN_CHANGE()),
-		     SIGNAL(textChanged()));
-
 	connect(this,SIGNAL(SCN_MODIFYATTEMPTRO()),
 		     SIGNAL(modificationAttempted()));
 
@@ -79,7 +73,7 @@ QextScintilla::QextScintilla(QWidget *parent,const char *name,WFlags f) :
 	connect(this,SIGNAL(QSCN_SELCHANGED(bool)),
 		     SLOT(handleSelectionChanged(bool)));
 
-#if defined(Q_OS_WIN32) || defined(Q_OS_WIN64)
+#if defined(Q_OS_WIN)
 	setEolMode(EolWindows);
 #elif defined(Q_OS_MAC)
 	setEolMode(EolMac);
@@ -100,12 +94,15 @@ QextScintilla::QextScintilla(QWidget *parent,const char *name,WFlags f) :
 
 	// Create the standard command set.
 	stdCmds = new QextScintillaCommandSet(this);
+
+	doc.display(this,0);
 }
 
 
 // The dtor.
 QextScintilla::~QextScintilla()
 {
+	doc.undisplay(this);
 }
 
 
@@ -905,7 +902,7 @@ void QextScintilla::foldExpand(int &line,bool doExpand,bool force,
 // fold all text.  This is mostly taken from SciTE.
 void QextScintilla::foldAll()
 {
-	SendScintilla(SCI_COLOURISE,0,-1);
+	recolor();
 
 	int maxLine = SendScintilla(SCI_GETLINECOUNT);
 	bool expanding = TRUE;
@@ -978,8 +975,13 @@ void QextScintilla::foldLine(int line)
 void QextScintilla::handleModified(int pos,int mtype,const char *text,int len,
 				   int added,int line,int foldNow,int foldPrev)
 {
-	if (fold && (mtype & SC_MOD_CHANGEFOLD))
-		foldChanged(line,foldNow,foldPrev);
+	if (mtype & SC_MOD_CHANGEFOLD)
+	{
+		if (fold)
+			foldChanged(line,foldNow,foldPrev);
+	}
+	else if (mtype & (SC_MOD_INSERTTEXT | SC_MOD_DELETETEXT))
+		emit textChanged();
 }
 
 
@@ -1262,6 +1264,48 @@ void QextScintilla::setSelection(int lineFrom,int indexFrom,
 }
 
 
+// Set the background colour of selected text.
+void QextScintilla::setSelectionBackgroundColor(const QColor &col)
+{
+	SendScintilla(SCI_SETSELBACK,1,col);
+}
+
+
+// Set the foreground colour of selected text.
+void QextScintilla::setSelectionForegroundColor(const QColor &col)
+{
+	SendScintilla(SCI_SETSELFORE,1,col);
+}
+
+
+// Set the width of the caret.
+void QextScintilla::setCaretWidth(int width)
+{
+	SendScintilla(SCI_SETCARETWIDTH,width);
+}
+
+
+// Set the foreground colour of the caret.
+void QextScintilla::setCaretForegroundColor(const QColor &col)
+{
+	SendScintilla(SCI_SETCARETFORE,col);
+}
+
+
+// Set the background colour of the line containing the caret.
+void QextScintilla::setCaretLineBackgroundColor(const QColor &col)
+{
+	SendScintilla(SCI_SETCARETLINEBACK,col);
+}
+
+
+// Set the state of the background colour of the line containing the caret.
+void QextScintilla::setCaretLineVisible(bool enable)
+{
+	SendScintilla(SCI_SETCARETLINEVISIBLE,enable);
+}
+
+
 // Query the read-only state.
 bool QextScintilla::isReadOnly()
 {
@@ -1279,6 +1323,8 @@ void QextScintilla::setReadOnly(bool ro)
 // Append the given text.
 void QextScintilla::append(const QString &text)
 {
+	bool ro = ensureRW();
+
 	if (isUtf8())
 	{
 		QCString s = text.utf8();
@@ -1293,12 +1339,15 @@ void QextScintilla::append(const QString &text)
 	}
 
 	SendScintilla(SCI_EMPTYUNDOBUFFER);
+
+	setReadOnly(ro);
 }
 
 
 // Insert the given text at the given position.
 void QextScintilla::insertAt(const QString &text,int line,int index)
 {
+	bool ro = ensureRW();
 	long position = posFromLineIndex(line,index);
 
 	SendScintilla(SCI_BEGINUNDOACTION);
@@ -1309,6 +1358,8 @@ void QextScintilla::insertAt(const QString &text,int line,int index)
 		SendScintilla(SCI_INSERTTEXT,position,text.latin1());
 
 	SendScintilla(SCI_ENDUNDOACTION);
+
+	setReadOnly(ro);
 }
 
 
@@ -1434,14 +1485,15 @@ QString QextScintilla::text()
 // Return the text of a line.
 QString QextScintilla::text(int line)
 {
-	int buflen = lineLength(line);
+	int line_len = lineLength(line);
 
-	if (buflen < 1)
+	if (line_len < 1)
 		return QString();
 
-	char *buf = new char[buflen + 1];
+	char *buf = new char[line_len + 1];
 
 	SendScintilla(SCI_GETLINE,line,buf);
+	buf[line_len] = '\0';
 
 	QString qs = convertText(buf);
 	delete[] buf;
@@ -1453,12 +1505,16 @@ QString QextScintilla::text(int line)
 // Set the given text.
 void QextScintilla::setText(const QString &text)
 {
+	bool ro = ensureRW();
+
 	if (isUtf8())
 		SendScintilla(SCI_SETTEXT,text.utf8().data());
 	else
 		SendScintilla(SCI_SETTEXT,text.latin1());
 
 	SendScintilla(SCI_EMPTYUNDOBUFFER);
+
+	setReadOnly(ro);
 }
 
 
@@ -1529,9 +1585,13 @@ void QextScintilla::selectAll(bool select)
 // Delete all text.
 void QextScintilla::clear()
 {
+	bool ro = ensureRW();
+
 	SendScintilla(SCI_BEGINUNDOACTION);
 	SendScintilla(SCI_CLEARALL);
 	SendScintilla(SCI_ENDUNDOACTION);
+
+	setReadOnly(ro);
 }
 
 
@@ -2053,6 +2113,11 @@ void QextScintilla::setLexer(QextScintillaLexer *lex)
 	{
 		int i, nrStyles, bits;
 
+		wordChars = lex -> wordCharacters();
+
+		if (!wordChars)
+			wordChars = defaultWordChars;
+
 		bits = lex -> styleBits();
 		nrStyles = 1 << bits;
 
@@ -2105,7 +2170,10 @@ void QextScintilla::setLexer(QextScintillaLexer *lex)
 		lex -> refreshProperties();
 	}
 	else
+	{
+		wordChars = defaultWordChars;
 		SendScintilla(SCI_SETLEXER,SCLEX_NULL);
+	}
 }
 
 
@@ -2436,19 +2504,30 @@ void QextScintilla::autoCompleteFromDocument()
 }
 
 
-// Return TRUE if the current character is part of a word.
+// Return TRUE if the current character (ie. the one before the carat) is part
+// of a word.
 bool QextScintilla::currentCharInWord()
 {
-	char ch = SendScintilla(SCI_GETCHARAT,SendScintilla(SCI_GETCURRENTPOS));
+	long pos = SendScintilla(SCI_GETCURRENTPOS);
 
-	return isWordChar(ch);
+	if (pos <= 0)
+		return FALSE;
+
+	return isWordChar(SendScintilla(SCI_GETCHARAT,pos - 1));
 }
 
 
 // Check if a character can be in a word.
 bool QextScintilla::isWordChar(char ch) const
 {
-	return (strchr(wordChars,ch) != NULL);
+	return (ch != '\0' && strchr(wordChars,ch) != NULL);
+}
+
+
+// Recolour the document.
+void QextScintilla::recolor(int start,int end)
+{
+	SendScintilla(SCI_COLOURISE,start,end);
 }
 
 
@@ -2527,3 +2606,27 @@ void QextScintilla::setCallTipsVisible(int nr)
 {
 	maxCallTips = nr;
 }
+
+
+// Set the document to display.
+void QextScintilla::setDocument(const QextScintillaDocument &document)
+{
+	if (doc.pdoc != document.pdoc)
+	{
+		doc.undisplay(this);
+		doc.attach(document);
+		doc.display(this,&document);
+	}
+}
+
+
+// Ensure the document is read-write and return True if was was read-only.
+bool QextScintilla::ensureRW()
+{
+	bool ro = isReadOnly();
+
+	if (ro)
+		setReadOnly(FALSE);
+
+	return ro;
+}
