@@ -1,7 +1,7 @@
 // This module defines the "official" high-level API of the Qt port of
 // Scintilla.
 //
-// Copyright (c) 2003
+// Copyright (c) 2004
 // 	Riverbank Computing Limited <info@riverbankcomputing.co.uk>
 // 
 // This file is part of QScintilla.
@@ -30,6 +30,7 @@
 
 #include <qextscintillaglobal.h>
 #include <qextscintillabase.h>
+#include <qextscintilladocument.h>
 
 
 class QColor;
@@ -317,6 +318,11 @@ public:
 	//! \sa eolMode(), setEolMode()
 	void convertEols(EolMode mode);
 
+	//! Returns the attached document.
+	//!
+	//! \sa setDocument()
+	QextScintillaDocument document() {return doc;}
+
 	//! Mark the end of a sequence of actions that can be undone by a
 	//! single call to undo().
 	//!
@@ -562,6 +568,11 @@ public:
 	//! \sa markerFindNext()
 	int markerFindPrevious(int linenr,unsigned mask);
 
+	//! Recolours the document between the \a start and \a end positions.
+	//! \a start defaults to the start of the document and \a end defaults
+	//! to the end of the document.
+	virtual void recolor(int start = 0,int end = -1);
+
 	//! Register an image \a pm with ID \a id.  Registered images can be
 	//! displayed in auto-completion lists.
 	//!
@@ -625,6 +636,12 @@ public:
 	//! \sa callTipsVisible()
 	void setCallTipsVisible(int nr);
 
+	//! Attach the document \a document, replacing the currently attached
+	//! document.
+	//!
+	//! \sa document()
+	void setDocument(const QextScintillaDocument &document);
+
 	//! Set the background colour of marker \a mnr to \a col.  If \a mnr is
 	//! -1 then the colour of all markers is set.  The default is white.
 	//!
@@ -847,6 +864,25 @@ public slots:
 	//! \sa backspaceUnindents(), tabIndents(), setTabIndents()
 	virtual void setBackspaceUnindents(bool unindent);
 
+	//! Sets the foreground colour of the caret to \a col.
+	virtual void setCaretForegroundColor(const QColor &col);
+
+	//! Sets the background colour of the line containing the caret to \a
+	//! col.
+	//!
+	//! \sa setCaretLineVisible()
+	virtual void setCaretLineBackgroundColor(const QColor &col);
+
+	//! Enables or disables, according to \a enable, the background color
+	//! of the line containing the caret.
+	//!
+	//! \sa setCaretLineBackgroundColor()
+	virtual void setCaretLineVisible(bool enable);
+
+	//! Sets the width of the caret to \a width pixels.  A \a width of 0
+	//! makes the caret invisible.
+	virtual void setCaretWidth(int width);
+
 	//! Sets the cursor to the line \a line at the position \a index.
 	//!
 	//! \sa getCursorPosition()
@@ -976,6 +1012,16 @@ public slots:
 	virtual void setSelection(int lineFrom,int indexFrom,
 				  int lineTo,int indexTo);
 
+	//! Sets the background colour of selected text to \a col.
+	//!
+	//! \sa setSelectionForegroundColor()
+	virtual void setSelectionBackgroundColor(const QColor &col);
+
+	//! Sets the foreground colour of selected text to \a col.
+	//!
+	//! \sa setSelectionBackgroundColor()
+	virtual void setSelectionForegroundColor(const QColor &col);
+
 	//! If \a indent is TRUE then the tab key will indent a line rather
 	//! then insert a tab character.
 	//!
@@ -1158,6 +1204,8 @@ private:
 	bool currentCharInWord();
 	bool isWordChar(char ch) const;
 
+	bool ensureRW();
+
 	struct FindState
 	{
 		FindState() : inProgress(0) {}
@@ -1191,6 +1239,7 @@ private:
 	QString acWordList;
 	QString ctWordList;
 	QextScintillaCommandSet *stdCmds;
+	QextScintillaDocument doc;
 
 #if defined(Q_DISABLE_COPY)
 	QextScintilla(const QextScintilla &);
