@@ -1,6 +1,6 @@
 // This class defines the "official" low-level API.
 //
-// Copyright (c) 2003
+// Copyright (c) 2004
 // 	Riverbank Computing Limited <info@riverbankcomputing.co.uk>
 // 
 // This file is part of QScintilla.
@@ -1324,6 +1324,81 @@ public:
 		//!
 		SCI_COPYTEXT = 2420,
 
+		//!
+		SCI_SETSELECTIONMODE = 2422,
+
+		//!
+		SCI_GETSELECTIONMODE = 2423,
+
+		//!
+		SCI_GETLINESELSTARTPOSITION = 2424,
+
+		//!
+		SCI_GETLINESELENDPOSITION = 2425,
+
+		//!
+		SCI_LINEDOWNRECTEXTEND = 2426,
+
+		//!
+		SCI_LINEUPRECTEXTEND = 2427,
+
+		//!
+		SCI_CHARLEFTRECTEXTEND = 2428,
+
+		//!
+		SCI_CHARRIGHTRECTEXTEND = 2429,
+
+		//!
+		SCI_HOMERECTEXTEND = 2430,
+
+		//!
+		SCI_VCHOMERECTEXTEND = 2431,
+
+		//!
+		SCI_LINEENDRECTEXTEND = 2432,
+
+		//!
+		SCI_PAGEUPRECTEXTEND = 2433,
+
+		//!
+		SCI_PAGEDOWNRECTEXTEND = 2434,
+
+		//!
+		SCI_STUTTEREDPAGEUP = 2435,
+
+		//!
+		SCI_STUTTEREDPAGEUPEXTEND = 2436,
+
+		//!
+		SCI_STUTTEREDPAGEDOWN = 2437,
+
+		//!
+		SCI_STUTTEREDPAGEDOWNEXTEND = 2438,
+
+		//!
+		SCI_WORDLEFTEND = 2439,
+
+		//!
+		SCI_WORDLEFTENDEXTEND = 2440,
+
+		//!
+		SCI_WORDRIGHTEND = 2441,
+
+		//!
+		SCI_WORDRIGHTENDEXTEND = 2442,
+
+		//!
+		SCI_SETWHITESPACECHARS = 2443,
+
+		//!
+		SCI_SETCHARSDEFAULT = 2444,
+
+		//!
+		SCI_AUTOCGETCURRENT = 2445,
+
+		//!
+		SCI_ALLOCATE = 2446,
+
 		//!
 		SCI_HOMEWRAP = 2349,
 
@@ -1345,6 +1420,24 @@ public:
 		//!
 		SCI_LINECOPY = 2455,
 
+		//!
+		SCI_SETWRAPVISUALFLAGS = 2460,
+
+		//!
+		SCI_GETWRAPVISUALFLAGS = 2461,
+
+		//!
+		SCI_SETWRAPVISUALFLAGSLOCATION = 2462,
+
+		//!
+		SCI_GETWRAPVISUALFLAGSLOCATION = 2463,
+
+		//!
+		SCI_SETWRAPSTARTINDENT = 2464,
+
+		//!
+		SCI_GETWRAPSTARTINDENT = 2465,
+
 		//!
 		SCI_STARTRECORD = 3001,
 
@@ -1374,7 +1467,31 @@ public:
 		//! styling.
 		//! \a wParam is unused.
 		//! \a lParam is the name of the lexer.
-		SCI_SETLEXERLANGUAGE = 4006
+		SCI_SETLEXERLANGUAGE = 4006,
+	};
+
+	enum
+	{
+		SC_WRAPVISUALFLAG_NONE = 0x0000,
+		SC_WRAPVISUALFLAG_END = 0x0001,
+		SC_WRAPVISUALFLAG_START = 0x0002
+	};
+
+	enum
+	{
+		SC_WRAPVISUALFLAGLOC_DEFAULT = 0x0000,
+		SC_WRAPVISUALFLAGLOC_END_BY_TEXT = 0x0001,
+		SC_WRAPVISUALFLAGLOC_START_BY_TEXT = 0x0002
+	};
+
+	//! This enum defines the different selection modes.
+	//!
+	//! \sa SCI_GETSELECTIONMODE, SCI_SETSELECTIONMODE
+	enum
+	{
+		SC_SEL_STREAM = 0,
+		SC_SEL_RECTANGLE = 1,
+		SC_SEL_LINES = 2
 	};
 
 	enum
@@ -1523,7 +1640,8 @@ public:
 		STYLE_BRACEBAD = 35,
 		STYLE_CONTROLCHAR = 36,
 		STYLE_INDENTGUIDE = 37,
-		STYLE_LASTPREDEFINED = 39
+		STYLE_LASTPREDEFINED = 39,
+		STYLE_MAX = 127
 	};
 
 	enum
@@ -1565,6 +1683,7 @@ public:
 		INDIC_DIAGONAL = 3,
 		INDIC_STRIKE = 4,
 		INDIC_HIDDEN = 5,
+		INDIC_BOX = 6,
 		INDIC0_MASK = 0x20,
 		INDIC1_MASK = 0x40,
 		INDIC2_MASK = 0x80,
@@ -1831,7 +1950,7 @@ public:
 		//! Select the POV lexer.
 		SCLEX_POV = 39,
 
-		//! Select the Lout lexer.
+		//! Select the Basser Lout typesetting language lexer.
 		SCLEX_LOUT = 40,
 
 		//! Select the EScript lexer.
@@ -1844,7 +1963,61 @@ public:
 		SCLEX_NSIS = 43,
 
 		//! Select the MMIX assembly language lexer.
-		SCLEX_MMIXAL = 44
+		SCLEX_MMIXAL = 44,
+
+		//! Select the Clarion lexer.
+		SCLEX_CLW = 45,
+
+		//! Select the Clarion lexer with case insensitive keywords.
+		SCLEX_CLWNOCASE = 46,
+
+		//! Select the MPT text log file lexer.
+		SCLEX_LOT = 47,
+
+		//! Select the YAML lexer.
+		SCLEX_YAML = 48,
+
+		//! Select the TeX lexer.
+		SCLEX_TEX = 49,
+
+		//! Select the Metapost lexer.
+		SCLEX_METAPOST = 50,
+
+		//! Select the PowerBASIC lexer.
+		SCLEX_POWERBASIC = 51,
+
+		//! Select the Forth lexer.
+		SCLEX_FORTH = 52,
+
+		//! Select the Erlang lexer.
+		SCLEX_ERLANG = 53,
+
+		//! Select the Octave lexer.
+		SCLEX_OCTAVE = 54,
+
+		//! Select the MS SQL lexer.
+		SCLEX_MSSQL = 55,
+
+		//! Select the Verilog lexer.
+		SCLEX_VERILOG = 56,
+
+		//! Select the KIX-Scripts lexer.
+		SCLEX_KIX = 57,
+
+		//! Select the Gui4Cli lexer.
+		SCLEX_GUI4CLI = 58,
+
+		//! Select the Specman E lexer.
+		SCLEX_SPECMAN = 59,
+
+		//! Select the AutoIt3 lexer.
+		SCLEX_AU3 = 60,
+
+		//! Select the APDL lexer.
+		SCLEX_APDL = 61,
+
+		//! Select the Bash lexer.
+		SCLEX_BASH = 62,
 	};
 
 	//! Construct an empty QextScintillaBase with parent \a parent, name
@@ -1855,6 +2028,11 @@ public:
 	//! Destroys the QextScintillaBase instance.
 	virtual ~QextScintillaBase();
 
+	//! Returns a pointer to a QextScintillaBase instance, or 0 if there
+	//! isn't one.  This can be used by the higher level API to send
+	//! messages that aren't associated with a particular instance.
+	static QextScintillaBase *pool();
+
 	//! Send the Scintilla message \a msg with the optional parameters \a
 	//! wParam and \a lParam.
 	long SendScintilla(unsigned int msg,unsigned long wParam = 0,
