@@ -1,6 +1,6 @@
 // This module implements the QextScintillaLexerHTML class.
 //
-// Copyright (c) 2003
+// Copyright (c) 2004
 // 	Riverbank Computing Limited <info@riverbankcomputing.co.uk>
 // 
 // This file is part of QScintilla.
@@ -65,6 +65,13 @@ int QextScintillaLexerHTML::styleBits() const
 }
 
 
+// Return the string of characters that comprise a word.
+const char *QextScintillaLexerHTML::wordCharacters() const
+{
+        return "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789_-";
+}
+
+
 // Returns the foreground colour of the text for a style.
 QColor QextScintillaLexerHTML::color(int style) const
 {
@@ -296,7 +303,7 @@ QFont QextScintillaLexerHTML::font(int style) const
 	{
 	case Default:
 	case Entity:
-#if defined(Q_OS_WIN32) || defined(Q_OS_WIN64)
+#if defined(Q_OS_WIN)
 		f = QFont("Times New Roman",11);
 #else
 		f = QFont("times",14);
@@ -304,7 +311,7 @@ QFont QextScintillaLexerHTML::font(int style) const
 		break;
 
 	case HTMLComment:
-#if defined(Q_OS_WIN32) || defined(Q_OS_WIN64)
+#if defined(Q_OS_WIN)
 		f = QFont("Verdana",9);
 #else
 		f = QFont("lucidatypewriter",10);
@@ -332,7 +339,7 @@ QFont QextScintillaLexerHTML::font(int style) const
 	case ASPJavaScriptCommentDoc:
 	case ASPJavaScriptKeyword:
 	case ASPJavaScriptSymbol:
-#if defined(Q_OS_WIN32) || defined(Q_OS_WIN64)
+#if defined(Q_OS_WIN)
 		f = QFont("Comic Sans MS",9);
 #else
 		f = QFont("new century schoolbook",12);
@@ -357,7 +364,7 @@ QFont QextScintillaLexerHTML::font(int style) const
 	case PythonComment:
 	case ASPPythonComment:
 	case PHPComment:
-#if defined(Q_OS_WIN32) || defined(Q_OS_WIN64)
+#if defined(Q_OS_WIN)
 		f = QFont("Comic Sans MS",9);
 #else
 		f = QFont("new century schoolbook",12);
@@ -374,7 +381,7 @@ QFont QextScintillaLexerHTML::font(int style) const
 	case ASPVBScriptString:
 	case ASPVBScriptIdentifier:
 	case ASPVBScriptUnclosedString:
-#if defined(Q_OS_WIN32) || defined(Q_OS_WIN64)
+#if defined(Q_OS_WIN)
 		f = QFont("Lucida Sans Unicode",9);
 #else
 		f = QFont("new century schoolbook",12);
@@ -383,7 +390,7 @@ QFont QextScintillaLexerHTML::font(int style) const
 
 	case VBScriptKeyword:
 	case ASPVBScriptKeyword:
-#if defined(Q_OS_WIN32) || defined(Q_OS_WIN64)
+#if defined(Q_OS_WIN)
 		f = QFont("Lucida Sans Unicode",9);
 #else
 		f = QFont("new century schoolbook",12);
@@ -395,7 +402,7 @@ QFont QextScintillaLexerHTML::font(int style) const
 	case PythonSingleQuotedString:
 	case ASPPythonDoubleQuotedString:
 	case ASPPythonSingleQuotedString:
-#if defined(Q_OS_WIN32) || defined(Q_OS_WIN64)
+#if defined(Q_OS_WIN)
 		f = QFont("Courier New",10);
 #else
 		f = QFont("courier",12);
@@ -410,7 +417,7 @@ QFont QextScintillaLexerHTML::font(int style) const
 		break;
 
 	case PHPCommentLine:
-#if defined(Q_OS_WIN32) || defined(Q_OS_WIN64)
+#if defined(Q_OS_WIN)
 		f = QFont("Comic Sans MS",9);
 #else
 		f = QFont("new century schoolbook",12);
