@@ -3,31 +3,31 @@
     <name>ContextMenu</name>
     <message>
         <source>Undo</source>
-        <translation>Rückgängig</translation>
+        <translation type="obsolete">Rückgängig</translation>
     </message>
     <message>
         <source>Redo</source>
-        <translation>Wiederherstellen</translation>
+        <translation type="obsolete">Wiederherstellen</translation>
     </message>
     <message>
         <source>Cut</source>
-        <translation>Ausschneiden</translation>
+        <translation type="obsolete">Ausschneiden</translation>
     </message>
     <message>
         <source>Copy</source>
-        <translation>Kopieren</translation>
+        <translation type="obsolete">Kopieren</translation>
     </message>
     <message>
         <source>Paste</source>
-        <translation>Einfügen</translation>
+        <translation type="obsolete">Einfügen</translation>
     </message>
     <message>
         <source>Delete</source>
-        <translation>Löschen</translation>
+        <translation type="obsolete">Löschen</translation>
     </message>
     <message>
         <source>Select All</source>
-        <translation>Alles auswählen</translation>
+        <translation type="obsolete">Alles auswählen</translation>
     </message>
 </context>
 <context>
@@ -70,7 +70,7 @@
     </message>
     <message>
         <source>Move to start of line</source>
-        <translation>Zum Beginn der Zeile</translation>
+        <translation type="obsolete">Zum Beginn der Zeile</translation>
     </message>
     <message>
         <source>Move to end of line</source>
@@ -284,6 +284,58 @@
         <source>Copy current line</source>
         <translation>Aktuelle Zeile kopieren</translation>
     </message>
+    <message>
+        <source>Extend rectangular selection down one line</source>
+        <translation>Rechteckige Auswahl um eine Zeile nach unten erweitern</translation>
+    </message>
+    <message>
+        <source>Extend rectangular selection up one line</source>
+        <translation>Rechteckige Auswahl um eine Zeile nach oben erweitern</translation>
+    </message>
+    <message>
+        <source>Extend rectangular selection left one character</source>
+        <translation>Rechteckige Auswahl um ein Zeichen nach links erweitern</translation>
+    </message>
+    <message>
+        <source>Extend rectangular selection right one character</source>
+        <translation>Rechteckige Auswahl um ein Zeichen nach rechts erweitern</translation>
+    </message>
+    <message>
+        <source>Move to start of displayed line</source>
+        <translation>Zum Beginn der angezeigten Zeile</translation>
+    </message>
+    <message>
+        <source>Extend rectangular selection to first visible character in line</source>
+        <translation>Rechteckige Auswahl bis zum ersten sichtbaren Zeichen erweitern</translation>
+    </message>
+    <message>
+        <source>Move to end of displayed line</source>
+        <translation>Zum Ende der angezeigten Zeile</translation>
+    </message>
+    <message>
+        <source>Extend selection to end of displayed line</source>
+        <translation>Auswahl bis zum Ende der angezeigten Zeile erweitern</translation>
+    </message>
+    <message>
+        <source>Extend rectangular selection to end of line</source>
+        <translation>Rechteckige Auswahl bis zum Zeilenende erweitern</translation>
+    </message>
+    <message>
+        <source>Extend rectangular selection up one page</source>
+        <translation>Rechteckige Auswahl um eine Seite nach oben erweitern</translation>
+    </message>
+    <message>
+        <source>Extend rectangular selection down one page</source>
+        <translation>Rechteckige Auswahl um eine Seite nach unten erweitern</translation>
+    </message>
+    <message>
+        <source>Set zoom</source>
+        <translation>Zoom einstellen</translation>
+    </message>
+    <message>
+        <source>Formfeed</source>
+        <translation>Seitenumbruch</translation>
+    </message>
 </context>
 <context>
     <name>QextScintillaLexerCPP</name>
@@ -844,6 +896,117 @@
         <translation>Regulärer Ausdruck</translation>
     </message>
 </context>
+<context>
+    <name>QextScintillaLexerPerl</name>
+    <message>
+        <source>Default</source>
+        <translation>Standard</translation>
+    </message>
+    <message>
+        <source>Error</source>
+        <translation>Fehler</translation>
+    </message>
+    <message>
+        <source>Comment</source>
+        <translation>Kommentar</translation>
+    </message>
+    <message>
+        <source>POD</source>
+        <translation>POD</translation>
+    </message>
+    <message>
+        <source>Number</source>
+        <translation>Zahl</translation>
+    </message>
+    <message>
+        <source>Keyword</source>
+        <translation>Schlüsselwort</translation>
+    </message>
+    <message>
+        <source>Double-quoted string</source>
+        <translation>Zeichenkette in Anführungszeichen</translation>
+    </message>
+    <message>
+        <source>Single-quoted string</source>
+        <translation>Zeichenkette in Hochkommata</translation>
+    </message>
+    <message>
+        <source>Operator</source>
+        <translation>Operator</translation>
+    </message>
+    <message>
+        <source>Identifier</source>
+        <translation>Bezeichner</translation>
+    </message>
+    <message>
+        <source>Scalar</source>
+        <translation>Skalar</translation>
+    </message>
+    <message>
+        <source>Array</source>
+        <translation>Feld</translation>
+    </message>
+    <message>
+        <source>Hash</source>
+        <translation>Hash</translation>
+    </message>
+    <message>
+        <source>Symbol table</source>
+        <translation>Symboltabelle</translation>
+    </message>
+    <message>
+        <source>Regular expression</source>
+        <translation>Regulärer Ausdruck</translation>
+    </message>
+    <message>
+        <source>Substitution</source>
+        <translation>Ersetzung</translation>
+    </message>
+    <message>
+        <source>Backticks</source>
+        <translation>Backticks</translation>
+    </message>
+    <message>
+        <source>Data section</source>
+        <translation>Datensektion</translation>
+    </message>
+    <message>
+        <source>Here document delimiter</source>
+        <translation>Here Dokument-Begrenzer</translation>
+    </message>
+    <message>
+        <source>Single-quoted here document</source>
+        <translation>Here Dokument in Hochkommata</translation>
+    </message>
+    <message>
+        <source>Double-quoted here document</source>
+        <translation>Here Dokument in Anführungszeichen</translation>
+    </message>
+    <message>
+        <source>Backtick here document</source>
+        <translation>Here Dokument in Backticks</translation>
+    </message>
+    <message>
+        <source>Quoted string (q)</source>
+        <translation>Zeichenkette (q)</translation>
+    </message>
+    <message>
+        <source>Quoted string (qq)</source>
+        <translation>Zeichenkette (qq)</translation>
+    </message>
+    <message>
+        <source>Quoted string (qx)</source>
+        <translation>Zeichenkette (qx)</translation>
+    </message>
+    <message>
+        <source>Quoted string (qr)</source>
+        <translation>Zeichenkette (qr)</translation>
+    </message>
+    <message>
+        <source>Quoted string (qw)</source>
+        <translation>Zeichenkette (qw)</translation>
+    </message>
+</context>
 <context>
     <name>QextScintillaLexerPython</name>
     <message>
